@@ -4,13 +4,13 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.004001';
+our $VERSION = '0.005000';
 
-use List::AllUtils qw( all sort_by uniq );
+use List::AllUtils qw( sort_by uniq );
 use Stepford::Error;
 use Stepford::FinalStep;
 use Stepford::Graph ();
-use Stepford::Types qw( ArrayRef ArrayOfSteps ClassName HashRef Logger Step );
+use Stepford::Types qw( ArrayOfSteps HashRef Logger Step );
 
 use Moose;
 use MooseX::StrictConstructor;
@@ -189,7 +189,7 @@ Stepford::GraphBuilder - Represents a concrete plan for execution by a Stepford:
 
 =head1 VERSION
 
-version 0.004001
+version 0.005000
 
 =head1 DESCRIPTION
 
@@ -207,7 +207,7 @@ Dave Rolsky <drolsky@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 - 2017 by MaxMind, Inc.
+This software is copyright (c) 2014 - 2018 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
