@@ -4,11 +4,10 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.004001';
+our $VERSION = '0.005000';
 
 use Carp qw( croak );
 use List::AllUtils qw( any max );
-use Stepford::Types qw( File );
 
 # Sadly, there's no (sane) way to make Path::Class::File use this
 use Time::HiRes 1.9726 qw( stat );
@@ -22,26 +21,36 @@ before BUILD => sub {
     my $self = shift;
 
     my @not_files = sort map { $_->name } grep {
-        !(     $_->has_type_constraint
-            && $_->type_constraint->is_a_type_of(File) )
+        !( $_->has_type_constraint && _is_a_file_type( $_->type_constraint ) )
     } $self->productions;
 
     croak 'The '
         . ( ref $self )
         . ' class consumed the Stepford::Role::Step::FileGenerator role but contains'
-        . " the following productions which are not files: @not_files"
+        . " the following productions which are not a supported file type: @not_files"
         if @not_files;
 
     return;
 };
 
+sub _is_a_file_type {
+    my $type = shift;
+
+    return any { $type->is_a_type_of($_) } qw(
+        MooseX::Types::Path::Class::File
+        MooseX::Types::Path::Tiny::File
+        MooseX::Types::Path::Tiny::AbsFile
+        MooseX::Types::Path::Tiny::Path
+        MooseX::Types::Path::Tiny::AbsPath
+    );
+}
+
 sub last_run_time {
     my $self = shift;
 
     my @production_files
         = map { $self->${ \( $_->get_read_method ) } } $self->productions;
 
-    ## no critic (Subroutines::ProhibitExplicitReturnUndef)
     return undef if any { !-f } @production_files;
 
     my @times = map { ( stat $_ )[9] } @production_files;
@@ -65,7 +74,7 @@ Stepford::Role::Step::FileGenerator - A role for steps that generate files
 
 =head1 VERSION
 
-version 0.004001
+version 0.005000
 
 =head1 DESCRIPTION
 
@@ -80,8 +89,8 @@ This role provides the following methods:
 
 This method adds a wrapper to the BUILD method which checks that all of the
 class's productions are of the C<File> type provided by
-L<MooseX::Types::Path::Class>. The attributes can also be subtypes of this
-type.
+L<MooseX::Types::Path::Class> or one of the L<MooseX::Types::Path::Tiny> file
+types. The attributes can also be subtypes of these types.
 
 This check may be changed so that it is done as part of the class definition,
 if I can think of a way to do this sanely.
@@ -102,7 +111,7 @@ Dave Rolsky <drolsky@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 - 2017 by MaxMind, Inc.
+This software is copyright (c) 2014 - 2018 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
