@@ -3,27 +3,28 @@ package Stepford::Types::Internal;
 use strict;
 use warnings;
 
-our $VERSION = '0.004001';
+our $VERSION = '0.005000';
 
 use MooseX::Types::Common::String qw( NonEmptyStr );
-use MooseX::Types::Moose qw( ArrayRef Defined Str );
-use MooseX::Types::Path::Class qw( File );
-use Scalar::Util qw( blessed );
+use MooseX::Types::Moose qw( ArrayRef Str );
+use Moose::Util::TypeConstraints qw( enum );
 
 use MooseX::Types -declare => [
     qw(
         ArrayOfClassPrefixes
         ArrayOfDependencies
-        ArrayOfFiles
         ArrayOfSteps
         Logger
         PossibleClassName
         Step
+        OutputMode
         )
 ];
 
 use namespace::clean;
 
+enum OutputMode, [qw[ none txt boxart ascii svg graphviz graphml vcg gdl ]];
+
 subtype PossibleClassName, as Str, inline_as {
     ## no critic (Subroutines::ProtectPrivateSubs)
     $_[0]->parent->_inline_check( $_[1] ) . ' && '
@@ -42,13 +43,6 @@ subtype ArrayOfDependencies, as ArrayRef [NonEmptyStr];
 
 coerce ArrayOfDependencies, from NonEmptyStr, via { [$_] };
 
-subtype ArrayOfFiles, as ArrayRef [File], inline_as {
-    ## no critic (Subroutines::ProtectPrivateSubs)
-    $_[0]->parent->_inline_check( $_[1] ) . " && \@{ $_[1] } >= 1";
-};
-
-coerce ArrayOfFiles, from File, via { [$_] };
-
 duck_type Logger, [qw( debug info notice warning error )];
 
 role_type Step, { role => 'Stepford::Role::Step' };
@@ -57,6 +51,8 @@ subtype ArrayOfSteps, as ArrayRef [Step];
 
 coerce ArrayOfSteps, from Step, via { [$_] };
 
+no Moose::Util::TypeConstraints;
+
 1;
 
 # ABSTRACT: Internal type definitions for Stepford
@@ -73,7 +69,7 @@ Stepford::Types::Internal - Internal type definitions for Stepford
 
 =head1 VERSION
 
-version 0.004001
+version 0.005000
 
 =head1 SUPPORT
 
@@ -85,7 +81,7 @@ Dave Rolsky <drolsky@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 - 2017 by MaxMind, Inc.
+This software is copyright (c) 2014 - 2018 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
